# Security Policy

pysorteddict is not audited for use in secure systems. Nonetheless, if you find a critical vulnerability, feel free to
create an issue with the details (or a request to establish an alternative channel of communication). I can't guarantee
that I'll be able to fix it but will definitely take a look.
